#
# Barpanel "CLOCK" plugin
# 
# Copyright (C) 2005 - 2006, Federico Pelloni <federico.pelloni@gmail.com>
# Copyright (C) 2008 Job and Esther Technologies Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#

name = "Clock"
description = "Draw a digital clock and print today's date on the panel"

import barpanel, gtk, gobject, time

class CalendarWindow(barpanel.PopupWindow):
    def __init__(self, panel, plugin):
        barpanel.PopupWindow.__init__(self, panel)
        self.plugin = plugin
        self.set_header("Calendar", "Browse the calendar", panel.get_image_from_icon_name("stock_calendar", 24))
        cal = gtk.Calendar()
        self.add(cal)
        cal.show()
        if self.plugin.settings.has_key("configure_command"):
            btn = gtk.Button()
            btn.set_name("EdgeButton")
            btn.connect("clicked", self.onConfigureDateTime)
            btn.set_relief(gtk.RELIEF_NONE)
            box = gtk.HBox(False, 2)
            btn.add(box)
            img = panel.get_stock_image(gtk.STOCK_PREFERENCES, 24)
            box.add(img)
            btn.show_all()
            barpanel.tooltips.set_tip(btn, _("Configure date/time"))
            self.header.pack_end(btn, False)

    def onConfigureDateTime(self, a):
        barpanel.launch_command(self.plugin.settings['configure_command'])
        self.close()

class Plugin(barpanel.Plugin):
    def __init__(self, panel, settings):
        barpanel.Plugin.__init__(self, panel, settings)
        if settings.has_key('format'):
            self.format = settings['format']
        else:
            self.format = "<span weight=\"bold\">%H:%M:%S</span> %m/%d/%Y"
        self.set_border_width(0)

        self.cwindow = CalendarWindow(panel, self)
        
        btn = gtk.ToggleButton()
        btn.set_name("EdgeButton")
        btn.connect("toggled", self.cwindow.toggle)
        btn.connect("enter-notify-event", self.cwindow.toggleConditional)
        btn.set_relief(gtk.RELIEF_NONE)
        self.add(btn)

        if settings.has_key('desc') and settings['desc'] != None and len(settings['desc'])>0:
            barpanel.tooltips.set_tip(btn, settings['desc'])
        else:
            barpanel.tooltips.set_tip(btn, "Browse the calendar")

        box = gtk.VBox(False, 0)
        box.show()
        btn.add(box)
        
        self.label_time = gtk.Label()
        panel.update_font(self, self.label_time)
        self.label_time.set_alignment(0.5, 0.5)
        self.label_time.set_name("DigitLabel")
        self.label_time.show()
        
        self.update()
        
        box.add(self.label_time)

        if self.format.find("%c") >= 0 or \
                self.format.find("%S") >= 0 or \
                self.format.find("%T") >= 0 or \
                self.format.find("%X") >= 0:
            self.logDEBUG("Clock displaying seconds: update scheduled every second.")
            gobject.timeout_add(1000, self.update)
        else:
            self.logDEBUG("Clock not displaying seconds: updated scheduled once every minute.")
            gobject.timeout_add(60 * 1000, self.update)

    def update(self):
        try:
            now = time.localtime()
            self.label_time.set_markup(time.strftime('%s' % (self.format), now))
        except KeyboardInterrupt:
            pass
        return True
